@@ -19,6 +19,11 @@
 #ifndef _BABL_VERSION_H
 #define _BABL_VERSION_H
 
+#if !defined(BABL_INSIDE_BABL_H) && !defined(BABL_IS_BEING_COMPILED)
+#error "babl-version.h must not be included directly, include babl.h instead."
+#endif
+
+
 /***
  * babl version information
  *
@@ -28,8 +33,8 @@
  */
 
 #define BABL_MAJOR_VERSION 0
-#define BABL_MINOR_VERSION 0
-#define BABL_MICRO_VERSION 22
+#define BABL_MINOR_VERSION 1
+#define BABL_MICRO_VERSION 8
 
 /** Get the version information on the babl library */
 void   babl_get_version (int *major,
