@@ -1796,7 +1796,7 @@ int init (void);
 int
 init (void)
 {
-  Babl *rgbaF = babl_format_new (
+  const Babl *rgbaF = babl_format_new (
     babl_model ("RGBA"),
     babl_type ("float"),
     babl_component ("R"),
@@ -1804,7 +1804,7 @@ init (void)
     babl_component ("B"),
     babl_component ("A"),
     NULL);
-  Babl *rgba16 = babl_format_new (
+  const Babl *rgba16 = babl_format_new (
     babl_model ("RGBA"),
     babl_type ("u16"),
     babl_component ("R"),
@@ -1812,7 +1812,7 @@ init (void)
     babl_component ("B"),
     babl_component ("A"),
     NULL);
-  Babl *rgbaD = babl_format_new (
+  const Babl *rgbaD = babl_format_new (
     babl_model ("RGBA"),
     babl_type ("double"),
     babl_component ("R"),
@@ -1820,7 +1820,7 @@ init (void)
     babl_component ("B"),
     babl_component ("A"),
     NULL);
-  Babl *rgba8 = babl_format_new (
+  const Babl *rgba8 = babl_format_new (
     babl_model ("RGBA"),
     babl_type ("u8"),
     babl_component ("R"),
@@ -1828,7 +1828,7 @@ init (void)
     babl_component ("B"),
     babl_component ("A"),
     NULL);
-  Babl *rgbAF = babl_format_new (
+  const Babl *rgbAF = babl_format_new (
     babl_model ("RaGaBaA"),
     babl_type ("float"),
     babl_component ("Ra"),
@@ -1836,7 +1836,7 @@ init (void)
     babl_component ("Ba"),
     babl_component ("A"),
     NULL);
-  Babl *rgbA16 = babl_format_new (
+  const Babl *rgbA16 = babl_format_new (
     babl_model ("RaGaBaA"),
     babl_type ("u16"),
     babl_component ("Ra"),
@@ -1844,7 +1844,7 @@ init (void)
     babl_component ("Ba"),
     babl_component ("A"),
     NULL);
-  Babl *rgbA8 = babl_format_new (
+  const Babl *rgbA8 = babl_format_new (
     babl_model ("RaGaBaA"),
     babl_type ("u8"),
     babl_component ("Ra"),
@@ -1852,79 +1852,79 @@ init (void)
     babl_component ("Ba"),
     babl_component ("A"),
     NULL);
-  Babl *rgbF = babl_format_new (
+  const Babl *rgbF = babl_format_new (
     babl_model ("RGB"),
     babl_type ("float"),
     babl_component ("R"),
     babl_component ("G"),
     babl_component ("B"),
     NULL);
-  Babl *rgb16 = babl_format_new (
+  const Babl *rgb16 = babl_format_new (
     babl_model ("RGB"),
     babl_type ("u16"),
     babl_component ("R"),
     babl_component ("G"),
     babl_component ("B"),
     NULL);
-  Babl *rgb8 = babl_format_new (
+  const Babl *rgb8 = babl_format_new (
     babl_model ("RGB"),
     babl_type ("u8"),
     babl_component ("R"),
     babl_component ("G"),
     babl_component ("B"),
     NULL);
-  Babl *gaF = babl_format_new (
+  const Babl *gaF = babl_format_new (
     babl_model ("YA"),
     babl_type ("float"),
     babl_component ("Y"),
     babl_component ("A"),
     NULL);
-  Babl *gAF = babl_format_new (
+  const Babl *gAF = babl_format_new (
     babl_model ("YaA"),
     babl_type ("float"),
     babl_component ("Ya"),
     babl_component ("A"),
     NULL);
-  Babl *gF = babl_format_new (
+  const Babl *gF = babl_format_new (
     babl_model ("Y"),
     babl_type ("float"),
     babl_component ("Y"),
     NULL);
-  Babl *ga16 = babl_format_new (
+  const Babl *ga16 = babl_format_new (
     babl_model ("YA"),
     babl_type ("u16"),
     babl_component ("Y"),
     babl_component ("A"),
     NULL);
-  Babl *gA16 = babl_format_new (
+  const Babl *gA16 = babl_format_new (
     babl_model ("YaA"),
     babl_type ("u16"),
     babl_component ("Ya"),
     babl_component ("A"),
     NULL);
-  Babl *g16 = babl_format_new (
+  const Babl *g16 = babl_format_new (
     babl_model ("Y"),
     babl_type ("u16"),
     babl_component ("Y"),
     NULL);
-  Babl *ga8 = babl_format_new (
+  const Babl *ga8 = babl_format_new (
     babl_model ("YA"),
     babl_type ("u8"),
     babl_component ("Y"),
     babl_component ("A"),
     NULL);
-  Babl *gA8 = babl_format_new (
+  const Babl *gA8 = babl_format_new (
     babl_model ("YaA"),
     babl_type ("u8"),
     babl_component ("Ya"),
     babl_component ("A"),
     NULL);
-  Babl *g8 = babl_format_new (
+  const Babl *g8 = babl_format_new (
     babl_model ("Y"),
     babl_type ("u8"),
     babl_component ("Y"),
     NULL);
-  Babl *yuv8 = babl_format_new (
+  const Babl *yuv8 = babl_format_new (
     "name", "Y'CbCr u8",
     "planar",
     babl_model ("Y'CbCr"),
@@ -1936,7 +1936,7 @@ init (void)
     babl_component ("Cb"),
     babl_component ("Cr"),
     NULL);
-  Babl *yuvF = babl_format_new (
+  const Babl *yuvF = babl_format_new (
     babl_model ("Y'CbCr"),
     babl_type ("float"),
     babl_component ("Y'"),
@@ -1944,7 +1944,7 @@ init (void)
     babl_component ("Cb"),
     babl_component ("Cr"),
     NULL);
-  Babl *yuvaF = babl_format_new (
+  const Babl *yuvaF = babl_format_new (
     babl_model ("Y'CbCrA"),
     babl_type ("float"),
     babl_component ("Y'"),
